<?php
/**
 * cryptocurrency-exchange Theme Functions
 */

//Crypto Theme URL
define("CRYPTO_THEME_URL", get_template_directory_uri());
define("CRYPTO_THEME_DIR", get_template_directory());

//cryptocurrency-exchange Theme Option Panel CSS and JS Backend
add_action('wp_enqueue_scripts','cryptocurrency_exchange_backend_resources');

//On theme activation add defaults theme settings and data
add_action( 'after_setup_theme', 'cryptocurrency_exchange_default_theme_options_setup' );

//Include Customizer File
require( get_template_directory() . '/include/customizer.php' );

//Add Theme Support Like - featured image, image crop, post format, rss feed
add_theme_support('post-thumbnails');			// featured image
add_theme_support('automatic-feed-links');		//	rss feed

// Set the content_width with 900
if ( ! isset( $content_width ) ) $content_width = 900;

function cryptocurrency_exchange_default_theme_options_setup() {
	// Load text domain for translation-ready
    load_theme_textdomain( 'cryptocurrency-exchange', CRYPTO_THEME_DIR . '/languages' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'title-tag' );
	
	add_theme_support( 'customize-selective-refresh-widgets' );
}

/**
 * cryptocurrency-exchange - Load Theme Option Panel CSS and JS Start
 */
function cryptocurrency_exchange_backend_resources(){
	// cryptocurrency-exchange theme css
	
	wp_enqueue_style( 'bootstrap-min-css', get_template_directory_uri() . '/css/bootstrap/bootstrap.min.css');	
	wp_enqueue_style( 'cryptocurrency-exchange-animate-css', get_template_directory_uri() . '/css/animate.css');
	wp_enqueue_style( 'font-awesome-min-css', get_template_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style( 'crypto-flexslider-css', get_template_directory_uri() . '/css/flexslider.css');
	wp_enqueue_style( 'cryptocurrency-exchange-style', get_stylesheet_uri());
		
	//js
	wp_enqueue_script('jquery');
	wp_enqueue_script('bootstrap-min', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '', false );
	wp_enqueue_script('cryptocurrency-exchange-wow-js', get_template_directory_uri() . '/js/wow.js', array('jquery'), array('jquery'), '', false );
	wp_enqueue_script('crypto-flexslider-js', get_template_directory_uri() . '/js/jquery.flexslider.js', array('jquery'), '', false );
	wp_enqueue_script('cryptocurrency-exchange-main-js', get_template_directory_uri() . '/js/main.js', array('jquery'), '', false );
}

//cryptocurrency-exchange - Load Theme Option Panel CSS and JS End

//Register area for custom menu
add_action( 'init', 'cryptocurrency_exchange_menu' );
function cryptocurrency_exchange_menu() {
	register_nav_menu( 'primary-menu', __( 'Primary Menu','cryptocurrency-exchange' ) );
	require get_template_directory() . '/include/walker.php';
}
// Include Walker file

/**
 * cryptocurrency-exchange Widgets Start
 */
function cryptocurrency_exchange_theme_widgets() {
	
	// Blog / Page Sidebar Widget
	register_sidebar( array(
		'name' 			=> esc_html__( 'Sidebar Widget', 'cryptocurrency-exchange'),
		'id' 			=> 'sidebar-widget',
		'before_widget' => '<aside id="%1$s" class="widget sidebar-widget widget-color %2$s">',
		'after_widget' 	=> '</aside>',
		'before_title' 	=> '<h3 class="widget-title">',
		'after_title' 	=> '</h3>'
	));
	
	// Get Footer Layout Settings
	$cryptocurrency_exchange_footer_column_layout = get_theme_mod('cryptocurrency_exchange_footer_column_layout', 3);
	if($cryptocurrency_exchange_footer_column_layout == 1) $cryptocurrency_exchange_footer_class_name = "col-md-12 col-sm-12 col-xs-12";		// one column
	if($cryptocurrency_exchange_footer_column_layout == 2) $cryptocurrency_exchange_footer_class_name = "col-md-6 col-sm-6 col-xs-12";		// two column
	if($cryptocurrency_exchange_footer_column_layout == 3) $cryptocurrency_exchange_footer_class_name = "col-md-4 col-sm-6 col-xs-12";		// three column
	if($cryptocurrency_exchange_footer_column_layout == 4) $cryptocurrency_exchange_footer_class_name = "col-md-3 col-sm-6 col-xs-12";		// four column
	
	// Footer Widget 1
	register_sidebar( array(
		'name'			=> esc_html__( 'Footer Widget', 'cryptocurrency-exchange'),
		'id'			=> 'footer-widget',
		'description'	=> esc_html__( 'This is footer widget area of the theme', 'cryptocurrency-exchange'),
		'before_widget' => '<aside id="%1$s" class="'.$cryptocurrency_exchange_footer_class_name.' widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>',
	));	
}
add_action('widgets_init', 'cryptocurrency_exchange_theme_widgets');
// crypto Widgets End